@@ -27,6 +27,7 @@ int vasprintf (char **strp, const char *fmt, va_list ap);
 #include <libxml/HTMLparser.h>
 #include <libxml/HTMLtree.h>
 #include <libxml/relaxng.h>
+#include <libxslt/extensions.h>
 #include <ruby.h>
 
 #ifdef HAVE_RUBY_ENCODING_H
@@ -35,8 +36,6 @@ int vasprintf (char **strp, const char *fmt, va_list ap);
 #include <st.h>
 #endif
 
-int is_2_6_16(void) ;
-
 #ifndef UNUSED
 # if defined(__GNUC__)
 #  define MAYBE_UNUSED(name) name __attribute__((unused))
@@ -134,6 +133,8 @@ extern VALUE mNokogiriXslt ;
 #define NOKOGIRI_DEBUG_START(p)
 #define NOKOGIRI_DEBUG_END(p)
 
+#endif
+
 #ifndef RSTRING_PTR
 #define RSTRING_PTR(s) (RSTRING(s)->ptr)
 #endif
@@ -150,6 +151,10 @@ extern VALUE mNokogiriXslt ;
 #define RARRAY_LEN(a) RARRAY(a)->len
 #endif
 
+#ifndef __builtin_expect
+# if defined(__GNUC__)
+#  define __builtin_expect(expr, c) __builtin_expect((long)(expr), (long)(c))
+# endif
 #endif
 
 #endif
