@@ -9,21 +9,21 @@
 static VALUE new(int argc, VALUE *argv, VALUE klass)
 {
   xmlDocPtr xml_doc;
+  xmlNodePtr node;
   VALUE document;
   VALUE rest;
+  VALUE rb_node;
 
   rb_scan_args(argc, argv, "1*", &document, &rest);
 
   Data_Get_Struct(document, xmlDoc, xml_doc);
 
-  xmlNodePtr node = xmlNewDocFragment(xml_doc->doc);
-  if(node->doc->children)
-    node->ns = node->doc->children->ns;
+  node = xmlNewDocFragment(xml_doc->doc);
 
   NOKOGIRI_ROOT_NODE(node);
 
-  VALUE rb_node = Nokogiri_wrap_xml_node(klass, node);
-  rb_funcall2(rb_node, rb_intern("initialize"), argc, argv);
+  rb_node = Nokogiri_wrap_xml_node(klass, node);
+  rb_obj_call_init(rb_node, argc, argv);
 
   if(rb_block_given_p()) rb_yield(rb_node);
 
