@@ -42,7 +42,7 @@ module Nokogiri
       end
 
       ###
-      # Returns the index of the first node in self that is == to +node+. Returns nil if no match is found. 
+      # Returns the index of the first node in self that is == to +node+. Returns nil if no match is found.
       def index(node)
         each_with_index { |member, j| return j if member == node }
         nil
@@ -104,7 +104,7 @@ module Nokogiri
 
         each do |node|
           doc = node.document
-          search_ns = ns || doc.root ? doc.root.namespaces : {}
+          search_ns = ns || (doc.root ? doc.root.namespaces : {})
 
           xpaths = paths.map { |rule|
             [
@@ -257,7 +257,7 @@ module Nokogiri
       # Wrap this NodeSet with +html+ or the results of the builder in +blk+
       def wrap(html, &blk)
         each do |j|
-          new_parent = document.root.parse(html).first
+          new_parent = document.parse(html).first
           j.add_next_sibling(new_parent)
           new_parent.add_child(j)
         end
@@ -273,6 +273,13 @@ module Nokogiri
       ###
       # Convert this NodeSet to HTML
       def to_html *args
+        if Nokogiri.jruby?
+          options = args.first.is_a?(Hash) ? args.shift : {}
+          if !options[:save_with]
+            options[:save_with] = Node::SaveOptions::NO_DECLARATION | Node::SaveOptions::NO_EMPTY_TAGS | Node::SaveOptions::AS_HTML
+          end
+          args.insert(0, options)
+        end
         map { |x| x.to_html(*args) }.join
       end
 
