@@ -8,6 +8,12 @@ module Nokogiri
         @html = Nokogiri::HTML.parse(File.read(HTML_FILE))
       end
 
+      def test_nil_css
+        # Behavior is undefined but shouldn't break
+        assert @html.css(nil)
+        assert @html.xpath(nil)
+      end
+
       def test_exceptions_remove_newlines
         errors = @html.errors
         assert errors.length > 0, 'has errors'
@@ -87,7 +93,7 @@ module Nokogiri
         assert_nil doc.root
       end
 
-      unless %w[2 6] === LIBXML_VERSION.split('.')[0..1]
+      unless Nokogiri.uses_libxml? && %w[2 6] === LIBXML_VERSION.split('.')[0..1]
         # FIXME: this is a hack around broken libxml versions
         def test_to_xhtml_with_indent
           doc = Nokogiri::HTML('<html><body><a>foo</a></body></html>')
@@ -119,6 +125,18 @@ module Nokogiri
 
       def test_meta_encoding
         assert_equal 'UTF-8', @html.meta_encoding
+
+        html = Nokogiri::HTML(<<-eohtml)
+<html>
+  <head>
+    <meta http-equiv="X-Content-Type" content="text/html; charset=Shift_JIS">
+  </head>
+  <body>
+    foo
+  </body>
+</html>
+        eohtml
+        assert_nil html.meta_encoding
       end
 
       def test_meta_encoding=
@@ -126,6 +144,53 @@ module Nokogiri
         assert_equal 'EUC-JP', @html.meta_encoding
       end
 
+      def test_title
+        assert_equal 'Tender Lovemaking  ', @html.title
+        doc = Nokogiri::HTML('<html><body>foo</body></html>')
+        assert_nil doc.title
+      end
+
+      def test_title=()
+        doc = Nokogiri::HTML(<<eohtml)
+<html>
+  <head>
+    <title>old</title>
+  </head>
+  <body>
+    foo
+  </body>
+</html>
+eohtml
+        doc.title = 'new'
+        assert_equal 'new', doc.title
+
+        doc = Nokogiri::HTML(<<eohtml)
+<html>
+  <head>
+  </head>
+  <body>
+    foo
+  </body>
+</html>
+eohtml
+        doc.title = 'new'
+        assert_equal 'new', doc.title
+
+        doc = Nokogiri::HTML(<<eohtml)
+<html>
+  <body>
+    foo
+  </body>
+</html>
+eohtml
+        doc.title = 'new'
+        if Nokogiri.uses_libxml?
+          assert_nil doc.title
+        else
+          assert_equal 'new', doc.title
+        end
+      end
+
       def test_meta_encoding_without_head
         html = Nokogiri::HTML('<html><body>foo</body></html>')
         assert_nil html.meta_encoding
@@ -167,6 +232,15 @@ module Nokogiri
         }
       end
 
+      def test_parse_temp_file
+        temp_html_file = Tempfile.new("TEMP_HTML_FILE")
+        File.open(HTML_FILE, 'rb') { |f| temp_html_file.write f.read }
+        temp_html_file.close
+        temp_html_file.open
+        assert_equal Nokogiri::HTML.parse(File.read(HTML_FILE)).xpath('//div/a').length, 
+          Nokogiri::HTML.parse(temp_html_file).xpath('//div/a').length
+      end
+
       def test_to_xhtml
         assert_match 'XHTML', @html.to_xhtml
         assert_match 'XHTML', @html.to_xhtml(:encoding => 'UTF-8')
