@@ -1,9 +1,7 @@
 require "helper"
 
 class TestMemoryLeak < Nokogiri::TestCase
-
   if ENV['NOKOGIRI_GC'] # turning these off by default for now
-
     def test_dont_hurt_em_why
       content = File.open("#{File.dirname(__FILE__)}/files/dont_hurt_em_why.xml").read
       ndoc = Nokogiri::XML(content)
@@ -14,6 +12,26 @@ class TestMemoryLeak < Nokogiri::TestCase
       end
     end
 
+    class BadIO
+      def read(*args)
+        raise 'hell'
+      end
+
+      def write(*args)
+        raise 'chickens'
+      end
+    end
+
+    def test_for_mem_leak_on_io_callbacks
+      io = File.open SNUGGLES_FILE
+      Nokogiri::XML.parse(io)
+
+      (10**10).times do
+        Nokogiri::XML.parse(BadIO.new) rescue nil
+        doc.write BadIO.new rescue nil
+      end
+    end
+
     def test_for_memory_leak
       begin
         #  we don't use Dike in any tests, but requiring it has side effects
@@ -42,39 +60,6 @@ class TestMemoryLeak < Nokogiri::TestCase
         puts "\ndike is not installed, skipping memory leak test"
       end
     end
-
-    if Nokogiri.ffi?
-      [ ['Node', 'p', nil],
-        ['CDATA', nil, 'content'],
-        ['Comment', nil, 'content'],
-        ['DocumentFragment', nil],
-        ['EntityReference', nil, 'p'],
-        ['ProcessingInstruction', nil, 'p', 'content'] ].each do |klass, *args|
-
-        define_method "test_for_leaked_#{klass}_nodes" do
-          Nokogiri::LibXML.expects(:xmlAddChild).at_least(1) # more than once shows we're GCing properly
-          10.times {
-            xml = Nokogiri::XML("<root></root>")
-            2.times { Nokogiri::XML.const_get(klass).new(*(args.collect{|arg| arg || xml})) }
-            GC.start
-          }
-          GC.start
-        end
-
-      end
-
-      def test_for_leaked_attr_nodes
-        Nokogiri::LibXML.expects(:xmlFreePropList).at_least(1) # more than once shows we're GCing properly
-        10.times {
-          xml = Nokogiri::XML("<root></root>")
-          2.times { Nokogiri::XML::Attr.new(xml, "p") }
-          GC.start
-        }
-        GC.start
-      end
-
-    end # if ffi
-
   end # if NOKOGIRI_GC
 
   private
