@@ -217,7 +217,12 @@ module Nokogiri
       end
 
       def test_validate
-        assert_equal 44, @xml.validate.length
+        if Nokogiri.uses_libxml?
+          assert_equal 44, @xml.validate.length
+        else
+          xml = Nokogiri::XML.parse(File.read(XML_FILE), XML_FILE) {|cfg| cfg.dtdvalid}
+          assert_equal 37, xml.validate.length
+        end
       end
 
       def test_validate_no_internal_subset
@@ -329,12 +334,12 @@ module Nokogiri
       end
 
       def test_non_existant_function
-        # WTF.  I don't know why this is different between MRI and ffi.
+        # WTF.  I don't know why this is different between MRI and Jruby
         # They should be the same...  Either way, raising an exception
         # is the correct thing to do.
         exception = RuntimeError
 
-        if Nokogiri::VERSION_INFO['libxml']['platform'] == 'jruby'
+        if !Nokogiri.uses_libxml? || (Nokogiri.uses_libxml? && Nokogiri::VERSION_INFO['libxml']['platform'] == 'jruby')
           exception = Nokogiri::XML::XPath::SyntaxError
         end
 
@@ -406,7 +411,7 @@ module Nokogiri
       end
 
       # wtf...  osx's libxml sucks.
-      unless Nokogiri::LIBXML_VERSION =~ /^2\.6\./
+      unless !Nokogiri.uses_libxml? || Nokogiri::LIBXML_VERSION =~ /^2\.6\./
         def test_encoding
           xml = Nokogiri::XML(File.read(XML_FILE), XML_FILE, 'UTF-8')
           assert_equal 'UTF-8', xml.encoding
@@ -606,7 +611,7 @@ module Nokogiri
             <a:foo>hello from a</a:foo>
             <b:foo>hello from b</b:foo>
             <container xmlns:c="http://c.flavorjon.es/">
-              <c:foo>hello from c</c:foo>
+              <c:foo c:attr='attr-value'>hello from c</c:foo>
             </container>
           </root>
         EOX
@@ -620,6 +625,7 @@ module Nokogiri
         assert_equal 1, doc.xpath("//a:foo").length
         assert_equal 1, doc.xpath("//a:foo").length
         assert_equal 1, doc.xpath("//x:foo", "x" => "http://c.flavorjon.es/").length
+        assert_match %r{foo c:attr}, doc.to_xml
 
         doc.remove_namespaces!
 
@@ -629,6 +635,7 @@ module Nokogiri
         assert_equal 0, doc.xpath("//a:foo", namespaces).length
         assert_equal 0, doc.xpath("//a:foo", namespaces).length
         assert_equal 0, doc.xpath("//x:foo", "x" => "http://c.flavorjon.es/").length
+        assert_match %r{foo attr}, doc.to_xml
       end
 
       def test_subset_is_decorated
@@ -663,6 +670,28 @@ module Nokogiri
         assert @xml.root.respond_to?(:awesome!)
         assert @xml.children.respond_to?(:awesome!)
       end
+
+      def test_java_integration
+        if Nokogiri.jruby?
+          require 'java'
+          factory = javax.xml.parsers.DocumentBuilderFactory.newInstance
+          builder = factory.newDocumentBuilder
+          document = builder.newDocument
+          root = document.createElement("foo")
+          document.appendChild(root)
+          noko_doc = Nokogiri::XML::Document.wrap(document)
+          assert_equal 'foo', noko_doc.root.name
+
+          noko_doc = Nokogiri::XML(<<eoxml)
+<foo xmlns='hello'>
+  <bar xmlns:foo='world' />
+</foo>
+eoxml
+          dom = noko_doc.to_java
+          assert dom.kind_of? org.w3c.dom.Document
+          assert_equal 'foo', dom.getDocumentElement().getTagName()
+        end
+      end
     end
   end
 end
