@@ -30,6 +30,10 @@ module Nokogiri
         @list = @xml.css('employee')
       end
 
+      def test_break_works
+        assert_equal 7, @xml.root.elements.each { |x| break 7 }
+      end
+
       def test_filter
         list = @xml.css('address').filter('*[domestic="Yes"]')
         assert_equal(%w{ Yes } * 4, list.map { |n| n['domestic'] })
@@ -158,6 +162,16 @@ module Nokogiri
         set = html.xpath("/html/body/div")
         assert_equal set.first, set.search(".a").first
       end
+      
+      def test_css_search_with_namespace
+        fragment = Nokogiri::XML.fragment(<<-eoxml)
+          <html xmlns="http://www.w3.org/1999/xhtml">
+          <head></head>
+          <body></body>
+          </html>
+        eoxml
+        assert_nothing_raised{ fragment.children.search( 'body', { 'xmlns' => 'http://www.w3.org/1999/xhtml' }) }
+      end
 
       def test_double_equal
         assert node_set_one = @xml.xpath('//employee')
@@ -224,6 +238,11 @@ module Nokogiri
         end
       end
 
+      def test_dup_on_empty_set
+        empty_set = Nokogiri::XML::NodeSet.new @xml, []
+        assert_equal 0, empty_set.dup.length # this shouldn't raise null pointer exception
+      end
+
       def test_xmlns_is_automatically_registered
         doc = Nokogiri::XML(<<-eoxml)
           <root xmlns="http://tenderlovemaking.com/">
@@ -348,6 +367,12 @@ module Nokogiri
         assert length, employees.length
       end
 
+      def test_delete_on_empty_set
+        empty_set = Nokogiri::XML::NodeSet.new @xml, []
+        employee  = @xml.at_xpath("//employee")
+        assert_equal nil, empty_set.delete(employee)
+      end
+
       def test_unlink
         xml = Nokogiri::XML.parse(<<-eoxml)
         <root>
@@ -431,6 +456,19 @@ module Nokogiri
         assert_equal 'employee', @xml.search("//wrapper").first.children[0].name
       end
 
+      def test_wrap_a_fragment
+        frag = Nokogiri::XML::DocumentFragment.parse <<-EOXML
+          <employees>
+            <employee>hello</employee>
+            <employee>goodbye</employee>
+          </employees>
+        EOXML
+        employees = frag.xpath ".//employee"
+        employees.wrap("<wrapper/>")
+        assert_equal 'wrapper', employees[0].parent.name
+        assert_equal 'employee', frag.at(".//wrapper").children.first.name
+      end
+
       def test_wrap_preserves_document_structure
         assert_equal "employeeId",
                      @xml.at_xpath("//employee").children.detect{|j| ! j.text? }.name
@@ -495,6 +533,13 @@ module Nokogiri
         assert_equal employees.length, employees[0, employees.length].length
       end
 
+      def test_slice_on_empty_node_set
+        empty_set = Nokogiri::XML::NodeSet.new @xml, []
+        assert_equal nil, empty_set[99]
+        assert_equal nil, empty_set[99..101]
+        assert_equal nil, empty_set[99,2]
+      end
+
       def test_slice_waaaaaay_off_the_end
         xml = Nokogiri::XML::Builder.new {
           root { 100.times { div } }
@@ -549,6 +594,12 @@ module Nokogiri
         assert_equal [employees[2]], (first_set & second_set).to_a
       end
 
+      def test_intersection_on_empty_set
+        empty_set = Nokogiri::XML::NodeSet.new @xml
+        employees = @xml.search("//employee")
+        assert_equal 0, (empty_set & employees).length
+      end
+
       def test_include?
         employees = @xml.search("//employee")
         yes = employees.first
@@ -558,6 +609,12 @@ module Nokogiri
         assert ! employees.include?(no)
       end
 
+      def test_include_on_empty_node_set
+        empty_set = Nokogiri::XML::NodeSet.new @xml, []
+        employee  = @xml.at_xpath("//employee")
+        assert ! empty_set.include?(employee)
+      end
+
       def test_children
         employees = @xml.search("//employee")
         count = 0
